@@ -3,7 +3,7 @@ use Mojo::Base 'Mojolicious::Plugin';
 use Time::HiRes qw/gettimeofday tv_interval/;
 use Net::Prometheus;
 
-our $VERSION = '0.9.1';
+our $VERSION = '0.9.2';
 
 has prometheus => sub { state $prom = Net::Prometheus->new };
 has route => sub {undef};
@@ -147,7 +147,7 @@ this plugin will also export
 
 =head1 AUTHOR
 
-Vidar Tyldum, L<mailto:vidar@tyldum.com>
+Vidar Tyldum
 
 =head1 COPYRIGHT AND LICENSE
 Copyright (C) 2017, Vidar Tyldum
